@@ -272,6 +272,9 @@ class SphinxQuerySet(object):
         kwargs = dict([('_%s' % (key,), value) for key, value in kwargs.iteritems() if key in self.available_kwargs])
         return kwargs
 
+    def get_query_set(self):
+        return self.model.objects.all()
+
     def set_options(self, **kwargs):
         kwargs = self._format_options(**kwargs)
         return self._clone(**kwargs)
@@ -402,7 +405,10 @@ class SphinxQuerySet(object):
 
         client = self._get_sphinx_client()
 
+        params = []
+
         if self._sort:
+            params.append('sort=%s' % (self._sort,))
             client.SetSortMode(*self._sort)
         
         if isinstance(self._weights, dict):
@@ -410,7 +416,9 @@ class SphinxQuerySet(object):
         else:
             # assume its a list
             client.SetWeights(map(int, self._weights))
-        
+        params.append('weights=%s' % (self._weights,))
+
+        params.append('matchmode=%s' % (self._mode,))
         client.SetMatchMode(self._mode)
         
         def _handle_filters(filter_list, exclude=False):
@@ -463,19 +471,24 @@ class SphinxQuerySet(object):
 
         # Include filters
         if self._filters:
+            params.append('filters=%s' % (self._filters,))
             _handle_filters(self._filters)
 
         # Exclude filters
         if self._excludes:
+            params.append('excludes=%s' % (self._excludes,))
             _handle_filters(self._excludes, True)
         
         if self._groupby:
+            params.append('groupby=%s' % (self._groupby,))
             client.SetGroupBy(self._groupby, self._groupfunc, self._groupsort)
 
         if self._anchor:
+            params.append('geoanchor=%s' % (self._anchor,))
             client.SetGeoAnchor(*self._anchor)
 
         if self._rankmode:
+            params.append('rankmode=%s' % (self._rankmode,))
             client.SetRankingMode(self._rankmode)
 
         if not self._limit > 0:
@@ -505,7 +518,7 @@ class SphinxQuerySet(object):
         elif not results['matches']:
             results = EMPTY_RESULT_SET
         
-        logging.debug('Found %s results for search query %s', results['total'], self._query)
+        logging.debug('Found %s results for search query %s on %s with params: %s', results['total'], self._query, self._index, ', '.join(params))
         
         return results
 
@@ -526,7 +539,7 @@ class SphinxQuerySet(object):
             
         if self.model:
             if results['matches']:
-                queryset = self.model.objects.all()
+                queryset = self.get_query_set()
                 if self._select_related:
                     queryset = queryset.select_related(*self._select_related_fields, **self._select_related_args)
                 if self._extra:
@@ -742,7 +755,7 @@ class SphinxRelation(SphinxSearch):
                     ids.append(value)
                 else:
                     ids.extend()
-            qs = self.model.objects.filter(pk__in=set(ids))
+            qs = self.get_query_set().filter(pk__in=set(ids))
             if self._select_related:
                 qs = qs.select_related(*self._select_related_fields,
                                        **self._select_related_args)
